"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChunkDoesNotExistError = exports.NullDepotError = exports.InstantiateStaticClassError = exports.IllegalStateError = exports.IllegalParameterError = exports.ValueMalformedError = exports.KeyNotFoundError = exports.KeyConflictError = void 0;
class ErrorTemplate extends Error {
    constructor(message) {
        super(message);
        this.name = "ErrorTemplate";
    }
}
class KeyConflictError extends ErrorTemplate {
    constructor(key) {
        super(`Key '${key}' already exists in Depot`);
        this.name = "KeyConflictError";
    }
}
exports.KeyConflictError = KeyConflictError;
class KeyNotFoundError extends ErrorTemplate {
    constructor(key) {
        super(`Key ${key} does not exist in Depot`);
        this.name = "KeyNotFoundError";
    }
}
exports.KeyNotFoundError = KeyNotFoundError;
class ValueMalformedError extends ErrorTemplate {
    constructor(value) {
        super(`Value ${value} is not or cannot convert to a legal json instance`);
        this.name = "ValueMalformedError";
    }
}
exports.ValueMalformedError = ValueMalformedError;
class IllegalParameterError extends ErrorTemplate {
    constructor(message) {
        super(message);
        this.name = "IllegalParameter";
    }
}
exports.IllegalParameterError = IllegalParameterError;
class IllegalStateError extends ErrorTemplate {
    constructor(message) {
        super(message);
        this.name = "IllegalStateError";
    }
}
exports.IllegalStateError = IllegalStateError;
class InstantiateStaticClassError extends ErrorTemplate {
    constructor(className) {
        super(`${className} is a static class and shall not be instantiated.`);
        this.name = "InstantiateStaticClassError";
    }
}
exports.InstantiateStaticClassError = InstantiateStaticClassError;
class NullDepotError extends ErrorTemplate {
    constructor() {
        super("Depot has been destroyed and can no longer be accessed");
        this.name = "NullDepotError";
    }
}
exports.NullDepotError = NullDepotError;
class ChunkDoesNotExistError extends ErrorTemplate {
    constructor(chunkName) {
        super(`Chunk ${chunkName} does not exist`);
        this.name = "ChunkDoesNotExistError";
    }
}
exports.ChunkDoesNotExistError = ChunkDoesNotExistError;
//# sourceMappingURL=Errors.js.map