"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonWriter = exports.ChunkWriter = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const zstd = __importStar(require("zstd.ts"));
const Errors = __importStar(require("./Errors"));
class Writer {
}
class ChunkWriter extends Writer {
    constructor(basePath, option) {
        super();
        this.maxChunkSize = null;
        this.maxChunkCount = null;
        this.totalSize = 0;
        this.getChunkFileName = (index) => {
            return path.join(this.basePath, `${this.chunkName}-${index}.cdu`);
        };
        this.write = (data) => {
            const buffer = Buffer.from(data, "utf-8");
            const compressed = zstd.compressSync({ input: buffer });
            this.totalSize = compressed.length;
            if (this.maxChunkSize !== null) {
                const chunkCount = Math.ceil(this.totalSize / this.maxChunkSize);
                for (let i = 0; i < chunkCount; i++) {
                    const start = i * this.maxChunkSize;
                    const end = Math.min(start + this.maxChunkSize, this.totalSize);
                    const chunk = compressed.subarray(start, end);
                    fs.writeFileSync(this.getChunkFileName(i), chunk);
                }
            }
            else if (this.maxChunkCount !== null) {
                const chunkSize = Math.ceil(this.totalSize / this.maxChunkCount);
                for (let i = 0; i < this.maxChunkCount; i++) {
                    const start = i * chunkSize;
                    const end = Math.min(start + chunkSize, this.totalSize);
                    const chunk = compressed.subarray(start, end);
                    fs.writeFileSync(this.getChunkFileName(i), chunk);
                }
            }
            else {
                fs.writeFileSync(this.getChunkFileName(0), compressed);
            }
        };
        if (!option) {
            this.basePath = basePath;
            this.chunkName = Date.now().toString();
            return;
        }
        if (option.maxChunkSize && option.maxChunkCount) {
            throw new Errors.IllegalParameterError("You can only specify either maxChunkSize or maxChunkCount");
        }
        this.basePath = basePath;
        this.chunkName =
            option.chunkName || Date.now().toString();
        this.maxChunkSize = option.maxChunkSize || null;
        this.maxChunkCount = option.maxChunkCount || null;
    }
}
exports.ChunkWriter = ChunkWriter;
class JsonWriter extends Writer {
    constructor(fileName) {
        super();
        this.write = (data) => {
            fs.writeFileSync(this.fileName, data);
        };
        this.fileName = fileName;
    }
}
exports.JsonWriter = JsonWriter;
//# sourceMappingURL=Writer.js.map